@@ -9,7 +9,6 @@ from .version import __version__
 
 
 class OAuth2AuthExchangeError(Exception):
-
     def __init__(self, description):
         self.description = description
 
@@ -26,19 +25,21 @@ class Request(object):
         self.api = api
 
     def _full_url(self, path):
-        return '{protocol}://{host}/{base_path}{path}'.format(
+        return "{protocol}://{host}/{base_path}{path}".format(
             protocol=self.api.protocol,
             host=self.api.host,
             base_path=self.api.base_path,
-            path=path)
+            path=path,
+        )
 
     def _full_url_with_params(self, path, params):
-        return '{full_url}{full_query_with_params}'.format(
+        return "{full_url}{full_query_with_params}".format(
             full_url=self._full_url(path),
-            full_query_with_params=self._full_query_with_params(params))
+            full_query_with_params=self._full_query_with_params(params),
+        )
 
     def _full_query_with_params(self, params):
-        params = '?{}'.format(urlencode(params)) if params else ''
+        params = "?{}".format(urlencode(params)) if params else ""
         return params
 
     def _post_body(self, params):
@@ -48,52 +49,49 @@ class Request(object):
         return self._full_url_with_params(path, parameters)
 
     def get(self, path, **kwargs):
-        return self.make_request(self.prepare_request('GET', path, kwargs))
+        return self.make_request(self.prepare_request("GET", path, kwargs))
 
     def post(self, path, **kwargs):
-        return self.make_request(self.prepare_request('POST', path, kwargs))
+        return self.make_request(self.prepare_request("POST", path, kwargs))
 
     def put(self, path, **kwargs):
-        return self.make_request(self.prepare_request('PUT', path, kwargs))
+        return self.make_request(self.prepare_request("PUT", path, kwargs))
 
     def patch(self, path, **kwargs):
-        return self.make_request(self.prepare_request('PATCH', path, kwargs))
+        return self.make_request(self.prepare_request("PATCH", path, kwargs))
 
     def delete(self, path, **kwargs):
-        return self.make_request(self.prepare_request('DELETE', path, kwargs))
+        return self.make_request(self.prepare_request("DELETE", path, kwargs))
 
     def prepare_request(self, method, path, params):
         url = None
         body = None
         headers = {}
 
-        if method in ['POST', 'PUT', 'PATCH', 'DELETE']:
+        if method in ["POST", "PUT", "PATCH", "DELETE"]:
             body = self._post_body(params)
-            headers = {'Content-type': 'application/x-www-form-urlencoded'}
+            headers = {"Content-type": "application/x-www-form-urlencoded"}
             url = self._full_url(path)
         else:
             url = self._full_url_with_params(path, params)
 
         return url, method, body, headers
 
-    def make_request(self, url, method='GET', body=None, headers=None):
+    def make_request(self, url, method="GET", body=None, headers=None):
         headers = headers or {}
-        if not 'User-Agent' in headers:
-            user_agent = '{} Python Client (version {})'.format(
-                self.api.api_name, __version__)
-            headers.update(
-                {'User-Agent': user_agent,
-                 'Connection': 'close'})
+        if not "User-Agent" in headers:
+            user_agent = "{} Python Client (version {})".format(
+                self.api.api_name, __version__
+            )
+            headers.update({"User-Agent": user_agent, "Connection": "close"})
         if self.api.api_key:
-            headers.update(
-                {'Authorization': 'Api-Key {}'.format(self.api.api_key)})
+            headers.update({"Authorization": "Api-Key {}".format(self.api.api_key)})
         else:
             if self.api.access_token:
-                headers.update({
-                    'Authorization': 'Bearer {}'.format(self.api.access_token)
-                })
-        http_obj = Http() if six.PY3 else Http(
-            disable_ssl_certificate_validation=True)
+                headers.update(
+                    {"Authorization": "Bearer {}".format(self.api.access_token)}
+                )
+        http_obj = Http() if six.PY3 else Http(disable_ssl_certificate_validation=True)
         return http_obj.request(url, method, body=body, headers=headers)
 
 
@@ -101,18 +99,18 @@ class OAuth2API(object):
 
     host = None
     base_path = None
-    protocol = 'http'
-    api_name = 'OAuth2API'
+    protocol = "http"
+    api_name = "OAuth2API"
     authorize_url = None
     redirect_uri = None
     access_token_url = None
-    access_token_field = 'access_token'
+    access_token_field = "access_token"
 
     def __init__(self, **kwargs):
-        self.client_id = kwargs.get('client_id')
-        self.client_secret = kwargs.get('client_secret')
-        self.access_token = kwargs.get('access_token')
-        self.redirect_uri = kwargs.get('redirect_uri')
+        self.client_id = kwargs.get("client_id")
+        self.client_secret = kwargs.get("client_secret")
+        self.access_token = kwargs.get("access_token")
+        self.redirect_uri = kwargs.get("redirect_uri")
 
     def get_authorize_url(self, scope=None):
         request = OAuth2AuthExchangeRequest(self)
@@ -126,44 +124,43 @@ class OAuth2API(object):
         request = OAuth2AuthExchangeRequest(self)
         return request.exchange_for_access_token(code=code)
 
-    def exchange_xauth_login_for_access_token(self, username, password,
-                                              scope=None):
+    def exchange_xauth_login_for_access_token(self, username, password, scope=None):
         request = OAuth2AuthExchangeRequest(self)
         return request.exchange_for_access_token(
-            username=username, password=password, scope=scope)
+            username=username, password=password, scope=scope
+        )
 
 
 class OAuth2AuthExchangeRequest(object):
-
     def __init__(self, api):
         self.api = api
 
     def _url_for_authorize(self, scope=None):
         client_params = {
-            'client_id': self.api.client_id,
-            'response_type': 'code',
-            'redirect_uri': self.api.redirect_uri
+            "client_id": self.api.client_id,
+            "response_type": "code",
+            "redirect_uri": self.api.redirect_uri,
         }
         if scope:
-            client_params.update(scope=' '.join(scope))
+            client_params.update(scope=" ".join(scope))
         url_params = urlencode(encode_parameters(client_params))
-        return '{}?{}'.format(self.api.authorize_url, url_params)
+        return "{}?{}".format(self.api.authorize_url, url_params)
 
-    def _data_for_exchange(self, code=None, username=None, password=None,
-                           scope=None):
+    def _data_for_exchange(self, code=None, username=None, password=None, scope=None):
         client_params = {
-            'client_id': self.api.client_id,
-            'client_secret': self.api.client_secret,
-            'redirect_uri': self.api.redirect_uri,
-            'grant_type': 'authorization_code'
+            "client_id": self.api.client_id,
+            "client_secret": self.api.client_secret,
+            "redirect_uri": self.api.redirect_uri,
+            "grant_type": "authorization_code",
         }
         if code:
             client_params.update(code=code)
         elif username and password:
-            client_params.update(username=username, password=password,
-                                 grant_type='password')
+            client_params.update(
+                username=username, password=password, grant_type="password"
+            )
             if scope:
-                client_params.update(scope=' '.join(scope))
+                client_params.update(scope=" ".join(scope))
         return urlencode(encode_parameters(client_params))
 
     def get_authorize_url(self, scope=None):
@@ -174,23 +171,24 @@ class OAuth2AuthExchangeRequest(object):
 
         url = self._url_for_authorize(scope=scope)
         response, __ = http_obj.request(url)
-        if response['status'] != '200':
+        if response["status"] != "200":
             raise OAuth2AuthExchangeError(
-                'The server returned a non-200 response for URL {}'.format(
-                    url))
-        redirected_to = response['content-location']
+                "The server returned a non-200 response for URL {}".format(url)
+            )
+        redirected_to = response["content-location"]
         return redirected_to
 
-    def exchange_for_access_token(self, code=None, username=None,
-                                  password=None, scope=None):
+    def exchange_for_access_token(
+        self, code=None, username=None, password=None, scope=None
+    ):
         data = self._data_for_exchange(code, username, password, scope)
         url = self.api.access_token_url
         http_obj = Http(disable_ssl_certificate_validation=True)
-        headers = {'Content-type': 'application/x-www-form-urlencoded'}
-        response, content = http_obj.request(url, method='POST', body=data,
-                                             headers=headers)
-        parsed_content = json.loads(content.decode('utf-8'))
-        if int(response['status']) != 200:
-            raise OAuth2AuthExchangeError(
-                parsed_content.get('error_message', ''))
+        headers = {"Content-type": "application/x-www-form-urlencoded"}
+        response, content = http_obj.request(
+            url, method="POST", body=data, headers=headers
+        )
+        parsed_content = json.loads(content.decode("utf-8"))
+        if int(response["status"]) != 200:
+            raise OAuth2AuthExchangeError(parsed_content.get("error_message", ""))
         return response, parsed_content
